---
title: "Stage 1 - Prepare"
author: "Skills4EOSC T2.3"
tags: 
    - FAIR-by-Design Learning Materials
    - FAIR Learning Objects
    - FAIR
    - Metadata
    - Learning objectives
    - Blooms taxonomy
hide:
    - toc
    - navigation
---

# Stage 1 - Prepare

!!! quote ""

    Before anything else, preparation is the key to success! -- *Alexander Graham Bell​*

## First things first. What is FAIR?

<div class="grid" markdown>

??? note "Findable"

    The editable learning material has a unique and persistent identifier (PID) and is described with sufficiently detailed metadata.

??? success "Accessible"

    The human and machine readable metadata and object are stored in a trusted repository with clear authentication and authorization procedures.

</div>

<div class="grid" markdown>

??? warning "Interoperable"

    The metadata describing the learning material follows a the RDA minimum metadata schema combined with agreed-upon controlled vocabularies.

    Formal, accessible, shared, and broadly applicable language(s) and format(s) are used to develop the material.

??? danger "Reusable"

    The learning material has a clear usage license (CC-BY-4.0 recommended) and accurate information on provenance.

</div>

## Adopt a metadata schema
  <a href="https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/02-Preparing%20FAIR%20Learning%20Objects/02-Preparing%20FAIR%20Learning%20Objects/#rda-minimal-metadata-for-learning-resources" class="btn btn-primary btn-lg btn-block">The RDA Minimal Metadata Set for Learning Resources</a>

!!! info ""

    === "Descriptive info fields"

        - **Title** =	The human readable name of the resource.
        - **Abstract / Description** =	A brief synopsis about or description of the learning resource
        - **Author(s)** =	Name of entity(ies) authoring the resource
        - **Primary Language** =	Language in which the resource was originally published or made available
        - **Keyword(s)** =	Keywords or tags used to describe the resource
        - **Version Date* =	Version date for the most recently published or broadcast resource

    === "Access info fields"

        - **URL to Resource** =	URL that resolves to the learning resource or to a "landing page" for the resource that contains important contextual information including the direct resolvable link to the resource, if applicable.
        - **Resource URL Type**	 = Designation of the identifier scheme used for the resource URL, e.g., DOI, ARK, Handle
        - **License** =	A license document that applies to this content, typically indicated by URL
        - **Access Cost**	= Choice stating whether or not there is a fee for use of the resource (yes, no, maybe)


    === "Educational info fields"

        - **Target Group (Audience)** =	Principal users(s) for which the resource was designed
        - **Learning Resource Type** =	The predominant type or kind that characterizes the learning resource
        - **Learning Outcome** =	Descriptions of what knowledge, skills or abilities a learner should acquire on completion of the resource
        - **Expertise (Skill) Level** =	Target skill level in the topic being taught; example values include beginner, intermediate, advanced

<small class="text-muted">
> [Hoebelheinrich, Nancy J, Biernacka, Katarzyna, Brazas, Michelle, Castro, Leyla Jael, Fiore, Nicola, Hellström, Margareta, Lazzeri, Emma, Leenarts, Ellen, Martinez Lavanchy, Paula Maria, Newbold, Elizabeth, Nurnberger, Amy, Plomp, Esther, Vaira, Lucia, van Gelder, Celia W G, & Whyte, Angus. (2022). Recommendations for a minimal metadata set to aid harmonised discovery of learning resources (1.0). Zenodo. https://doi.org/10.15497/RDA00073](https://doi.org/10.15497/RDA00073)
</small>

??? info "More on FAIR learning objects definition"

    Learn more about: 
    - [FAIR instructional design skills](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/01-FAIR%20skills%20%26%20principles/01-FAIR%20skills%20%26%20principles/#fair-instructional-design-skills)
    - [FAIR guiding principles](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/01-FAIR%20skills%20%26%20principles/01-FAIR%20skills%20%26%20principles/#fair-guiding-principles)
    - [FAIR learning objects](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/01-FAIR%20skills%20%26%20principles/01-FAIR%20skills%20%26%20principles/#fair-learning-objects)

## Start Ideating...

<div class="row">
  <div class="col-sm-4">
   <!-- <div class="card text-white bg-secondary mb-3" > -->
   <div class="card bg-light mb-3" >
      <!-- <div class="card-header text-white"> -->
      <div class="card-header"><i class="fa fa-fast-backward" aria-hidden="true"></i> Think backward</div>
      <div class="card-body">
        <h5 class="card-title">Step 1</h5>
        <p class="card-text">What are your desired effects, i.e. learning outcomes...</p>
      </div>
    </div>
  </div>

  <div class="col-sm-4">
    <div class="card bg-light mb-3" >
      <div class="card-header"><i class="fa fa-fast-backward" aria-hidden="true"></i> Think backward</div>
      <div class="card-body">
        <h5 class="card-title">Step 2</h5>
        <p class="card-text">How are you going to assess their achievement....</p>
      </div>
    </div>
  </div>

  <div class="col-sm-4">
    <div class="card bg-light mb-3" >
      <div class="card-header"><i class="fa fa-fast-backward" aria-hidden="true"></i> Think backward</div>
      <div class="card-body">
        <h5 class="card-title">Step 3</h5>
        <p class="card-text">How should you structure the material to reach them...</p>
      </div>
    </div>
  </div>

</div>

??? info "More on backward learning"

    [Steps of the backward learning process](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/02-Preparing%20FAIR%20Learning%20Objects/02-Preparing%20FAIR%20Learning%20Objects_cont/#backward-instructional-design-process)

## Define

<div class="grid cards" markdown>

-   :material-flag-checkered:{ .lg .middle } __Purpose__

    ---

    When and how the learning materials can be used and for what purposes?

-   :material-target-account:{ .lg .middle } __Target Audience__

    ---

    Is there anything specific that needs to be taken into account, such as cultural context?

-   :material-history:{ .lg .middle } __Prerequisites__

    ---

    What does the target audience need to know or understand before starting the learning process?


-   :material-target-account:{ .lg .middle } __Scope__

    ---

    Is it going to be a single learning unit, or a group such as a course?

-   :material-bullseye-arrow:{ .lg .middle } __Learning Objectives__

    ---

    What competences will be gained after successful completing of the learning process?

    ??? info "Be SMART"

        Objectives should be specific, ​measurable, ​attainable, ​relevant and ​time-bound​.

    ??? hint "Use Blooms Taxonomy"
    
        Formulate the objectives as actionable verb + observable knowledge, skill, attitude, behavior or ability.

    [:octicons-arrow-right-24: See more](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/02-Preparing%20FAIR%20Learning%20Objects/02-Preparing%20FAIR%20Learning%20Objects_cont/#defining-learning-objectives)

</div>


<a href="https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/01-FAIR%20skills%20%26%20principles/01-FAIR%20skills%20%26%20principles/" class="btn btn-dark text-white btn-lg btn-block">Start an in-depth training on the Prepare stage....</a>
<a href="https://fair-by-design-methodology.github.io/FAIR-by-Design_Book/4%20-%20FAIR-by-design%20learning%20materials%20creation/4.1%20-%20Workflow%20stages%20description/411-prepare/" class="btn btn-dark text-white btn-lg btn-block">FAIR-by-Design Methodology: Prepare stage....</a>
