---
title: "Stage 4 - Produce"
author: "Skills4EOSC T2.3"
tags: 
    - FAIR-by-Design Learning Materials
    - FAIR Learning Objects
    - Tools
    - Formats
    - Accessibility
    - Internal QA
hide:
    - toc
    - navigation
---

# Stage 4 - Produce

!!! quote ""

    To contrive is nothing! To construct is something! To produce is everything! - *Edward Rickenbacker​*

## Choose Tools & Formats

<div class="grid" markdown>

??? info "Collaborative environment for team work"

    Choose an environment for producing the learning material that will enable multiple people to work on the same material at one. Two examples are workplace or GitHub (find out more <a href='https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20–%20Produce/08-Development%20Tools/08-Introduction%20to%20Markdown%20and%20Git/'>here</a>). Replicate the folder tree in the environment and start using the provided templates to generate the content.

??? tip "Granular versioning for easy rollback"

    Versioning helps you maintain control over your changes. If the collaborative environment does not provide versioning and history retention then keep a history of the files by adopting a naming convention such as combining the file name with an increasing version number.

??? success "Open file formats to foster reuse "

    For other people to reuse your materials they should be made available using open file formats (docx, pptx, pdf, md, html, etc.). If you use close file formats then you MUST clearly state the tools that have been used for development in your README file.

??? warning "Multimodal content to reach all audience"

    Don't forget to include different types of multimedia to provide support for different learning modalities: read/write, auditory, visual, kinesthetic.
    
??? example "Two file sets: editable + final"

    Always work with and keep a history of your editable files. These are what matters for you and other instructors. The second set of final files should be obtained from the editable when needed (before distributing them to the learners). The final files should be kept on the learning platform only. In this way you don't need to worry about keeping the versions in sync.

??? bug "Don't forget to support co-creation"

    Truly FAIR learning materials should enable co-creation with external parties. If you don't use a collaborative environment that supports this from the start (such as GitHub), then think how are you going to enable this in the future and how are you going to deal with versioning then.

</div>

## Plan to reuse existing material? 

<div class="grid cards" markdown>

-   :material-license:{ .lg .middle } __Check the license__

    ---

    The existing material is available under a CC license, but it is different than the one you plan to use for your materials...

    === "I want to reuse it as a whole"

        You can't use something that is licensed with ND (no derivatives). In this case you must follow the rules on combining and adapting CC material. [Read more...](https://creativecommons.org/faq/#combining-and-adapting-cc-material)

    === "I want to reuse a small part of it"

        No problem, you can reuse any existing CC licensed material in your learning materials as long as the reused portion is used as a showcase or to make a specific point and it is not the core of your work. If the work is licensed with ND, do not modify it while reusing.
    
    === "Learn more about IPR"

        [:octicons-arrow-right-24: How Intellectual Property Rights (IPR) protect the interests of the creators and owners by providing them with rights over their creation?](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/02-Preparing%20FAIR%20Learning%20Objects/02-Preparing%20FAIR%20Learning%20Objects/#intellectual-property-rights-ipr)

    [:octicons-arrow-right-24: Go to CC licensing FAQ](https://creativecommons.org/faq/#before-using-cc-licensed-material)

-   :material-card-account-details-outline:{ .lg .middle } __Attribute__

    ---

    All CC licenses require that you attribute the author, and this rule is recommended even if the license is public domain CC-0.

    If the work you are reusing has a copyright notice ("© some text") you need to reproduce it while you credit the work.

    You should also be able to remove attribution upon request.

    === "Use the authors recommended attribution"

        If the original author has provided a cite-as information, use it to attribute the work.

    === "Use TASL"

        Provide the Title, Author, Source and License of the work that you are reusing. 
        
        Source is the URL to the original work.

        If there is a URL to the author personal pages, provide it together with the name.

        Provide the name of the license and a URL to the license. 
    
    === "Examples"
        > Examples are taken from [Best Practices for Creative Commons attributions - how to attribute works you reuse under a Creative Commons license](https://www.newmediarights.org/guide/how_to/creative_commons/best_practices_creative_commons_attributions) submitted by [New Media Rights](https://www.newmediarights.org/) available under a [CC BY-NC 3.0 US DEED](https://creativecommons.org/licenses/by-nc/3.0/us/)

        - Webpage/Blog - Title (with link to original work), author (or username) (with link to author's website), and license (with link).

            > [Undercover Vampire Policeman](https://chriszabriskie.bandcamp.com/album/undercover-vampire-policeman) by [Chris Zabriskie](https://chriszabriskie.bandcamp.com/), available under a [Creative Commons Attribution 4.0 License](http://creativecommons.org/licenses/by/4.0/)

        - Book – Title, author, license written somewhere near the title and author if it’s a hard copy or if it’s an online book you should include a link to the licensed terms.

            > [From Dust to Digital: Ten Years of the Endangered Archives Programme](https://books.google.com/books?id=ImO3BgAAQBAJ&pg=PR4&dq=creative+commons+4.0&hl=en&sa=X&ved=0CEoQ6AEwCGoVChMIspCXhPPxxgIVSF0eCh27NA5X#v=onepage&q=creative%20commons%204.0&f=false) by Maja Kominko under a Creative Commons Attribution Non-commercial Non-Derivative 4.0 International license (CC BY-NC-ND 4.0)

        - Online Video - Title, author, license written into credits at end of video.  Ideally make the text clickable to the original work.  Put links to the original work and the license terms in the information section for the particular work (i.e. on the right in YouTube).

            > [http://www.youtube.com/watch?v=fDbbdeIXO0w#t=3m0s](http://www.youtube.com/watch?v=fDbbdeIXO0w#t=3m0s)

        - Podcast/Audio - Title, author, license read at the end of the entire work.
            > [“Je Suis Rick Springfield”](http://www.jonathancoulton.com/wiki/Je_Suis_Rick_Springfield) from the album [Artificial Heart](http://www.jonathancoulton.com/wiki/Artificial_Heart_(album)), by Jonathan Coulton, used under a [Creative Commons Attribution-Noncommercial 3.0 Unported License](http://creativecommons.org/licenses/by-nc/3.0/)

        - Photo/Drawing/Illustration – Title, author, license (with link online) or in close proximity to the tangible work (either in the border or directly on the work, if applicable).

            > “[Comcast protest](http://www.flickr.com/photos/ari/8503459/in/set-214952/)” by Flikr user [Steve Rhodes](http://www.flickr.com/photos/ari/) used under [Creative Commons Attribution 2.0 license](http://creativecommons.org/licenses/by/2.0/deed.en)

    === "Learn more"

        [:octicons-arrow-right-24: Attribution and Citing](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/02-Preparing%20FAIR%20Learning%20Objects/02-Preparing%20FAIR%20Learning%20Objects/#attribution-and-citing)

    [:octicons-arrow-right-24: How to handle attribution?](https://courses.lumenlearning.com/suny-oerguide/chapter/how-to-handle-attribution/)

</div>


## Accessibility

!!! tip ""

    The developed learning materials should cover the widest range of learner variability including the ones that use or do not use assistive technology.

<div class="card w-100 mb-3">
  <div class="row no-gutters">
    <div class="col-md-4" style="width: 18rem;">
      <img class="card-img" src="../../attachments/universal-access-6602642_640.png" alt="Accessibility logo"/>
      <p class="card-text"><small class="text-muted">
                Image by <a href="https://pixabay.com/users/inspire-studio-22128832/?utm_source=link-attribution&utm_medium=referral&utm_campaign=image&utm_content=6602642">J S</a> from <a href="https://pixabay.com//?utm_source=link-attribution&utm_medium=referral&utm_campaign=image&utm_content=6602642">Pixabay</a></small>
                </p>
    </div>
    <div class="col-md-8" style="width: 36rem;">
      <div class="card-body">
            <h2 class="card-title">Standards</h2>
            <p class="card-text">There are several standards that govern the rules on level of accessibility. Three conformance levels exist, you should aim for AA which is the middle one. </p>
            <p class="card-text">Most commonly used is the <a href="https://www.w3.org/WAI/standards-guidelines/wcag/">W3C Web Content Accessibility Guidelines (WCAG) standard version 2.1</a>.</p>
            <p class="card-text">PDF document accessibility is measured with a separate technical specification <a href="https://pdfua.foundation/en/why-pdf-ua/">PDF/UA (Universal Accessibility)</a>.</p>
            <a href="https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20%E2%80%93%20Produce/11-Accessibility/11-Checking_accessibility/" class="btn btn-primary stretched-link">Learn more</a>
      </div>
    </div>
  </div>
</div>

<div class="grid cards" markdown>

-   :material-human:{ .lg .middle } __Use accessibility evaluation tools!__

    ---

    Accessibility evaluation tools are not perfect. Even if they say that all is ok, it does not mean that your content is truly accessible. But they are a very good starting point.

    === "Slides"

        Use the integrated accessibility checker in Power Point:

        1. Open an existing presentation in PowerPoint and review the content. 
        2. Select the Review tab. 
        3. Select Check Accessibility.
        4. An Accessibility Checker pane will appear on the right with 'Inspection Results' displayed.

    === "Web content"

        Choose from the [Web Accessibility Evaluation Tools List](https://www.w3.org/WAI/test-evaluate/tools/list/) developed by W3C.

    === "PDF document"

        Check accessibility in Adobe Acrobat Pro.

        Open the PDF and then from the All tools menu on the left, select View more and then select Prepare for accessibility.

</div>

## Internal QA

<div class="grid cards" markdown>

- :material-quality-high: __QA Self-assessment__ to check if everything is as it should be
- :material-check-all: __Quantitative__ are all required elements produced
- :material-puzzle-check-outline: __Qualitative__ do all learning units provide materials to reach the learning objectives with different modalities 

</div>

​<a href="https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20%E2%80%93%20Produce/08-Development%20Tools/08-Introduction%20to%20Markdown%20and%20Git/" class="btn btn-dark text-white btn-lg btn-block">Start an in-depth training on the Produce stage....</a>
<a href="https://fair-by-design-methodology.github.io/FAIR-by-Design_Book/4%20-%20FAIR-by-design%20learning%20materials%20creation/4.1%20-%20Workflow%20stages%20description/414-produce/" class="btn btn-dark text-white btn-lg btn-block">FAIR-by-Design Methodology: Produce stage....</a>